# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.catalogs import template_pb2 as v1_dot_catalogs_dot_template__pb2


class ProductTemplateServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ProductTemplateCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductTemplateCreate",
            request_serializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateCreateRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateCreateResponse.FromString,
        )
        self.ProductTemplateRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductTemplateRead",
            request_serializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateReadRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateReadResponse.FromString,
        )
        self.ProductTemplateUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductTemplateUpdate",
            request_serializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateUpdateResponse.FromString,
        )
        self.ProductTemplateDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductTemplateDelete",
            request_serializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateDeleteResponse.FromString,
        )
        self.ProductCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductCreate",
            request_serializer=v1_dot_catalogs_dot_template__pb2.ProductCreateRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_template__pb2.ProductCreateResponse.FromString,
        )
        self.ProductRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductRead",
            request_serializer=v1_dot_catalogs_dot_template__pb2.ProductReadRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_template__pb2.ProductReadResponse.FromString,
        )
        self.ProductUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductUpdate",
            request_serializer=v1_dot_catalogs_dot_template__pb2.ProductUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_template__pb2.ProductUpdateResponse.FromString,
        )
        self.ProductDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductDelete",
            request_serializer=v1_dot_catalogs_dot_template__pb2.ProductDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_template__pb2.ProductDeleteResponse.FromString,
        )
        self.ProductAllRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductAllRead",
            request_serializer=v1_dot_catalogs_dot_template__pb2.ProductAllReadRequest.SerializeToString,
            response_deserializer=v1_dot_catalogs_dot_template__pb2.ProductAllReadResponse.FromString,
        )


class ProductTemplateServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ProductTemplateCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProductTemplateRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProductTemplateUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProductTemplateDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProductCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProductRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProductUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProductDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ProductAllRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_ProductTemplateServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ProductTemplateCreate": grpc.unary_unary_rpc_method_handler(
            servicer.ProductTemplateCreate,
            request_deserializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateCreateRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateCreateResponse.SerializeToString,
        ),
        "ProductTemplateRead": grpc.unary_unary_rpc_method_handler(
            servicer.ProductTemplateRead,
            request_deserializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateReadRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateReadResponse.SerializeToString,
        ),
        "ProductTemplateUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.ProductTemplateUpdate,
            request_deserializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateUpdateRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateUpdateResponse.SerializeToString,
        ),
        "ProductTemplateDelete": grpc.unary_unary_rpc_method_handler(
            servicer.ProductTemplateDelete,
            request_deserializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateDeleteRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_template__pb2.ProductTemplateDeleteResponse.SerializeToString,
        ),
        "ProductCreate": grpc.unary_unary_rpc_method_handler(
            servicer.ProductCreate,
            request_deserializer=v1_dot_catalogs_dot_template__pb2.ProductCreateRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_template__pb2.ProductCreateResponse.SerializeToString,
        ),
        "ProductRead": grpc.unary_unary_rpc_method_handler(
            servicer.ProductRead,
            request_deserializer=v1_dot_catalogs_dot_template__pb2.ProductReadRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_template__pb2.ProductReadResponse.SerializeToString,
        ),
        "ProductUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.ProductUpdate,
            request_deserializer=v1_dot_catalogs_dot_template__pb2.ProductUpdateRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_template__pb2.ProductUpdateResponse.SerializeToString,
        ),
        "ProductDelete": grpc.unary_unary_rpc_method_handler(
            servicer.ProductDelete,
            request_deserializer=v1_dot_catalogs_dot_template__pb2.ProductDeleteRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_template__pb2.ProductDeleteResponse.SerializeToString,
        ),
        "ProductAllRead": grpc.unary_unary_rpc_method_handler(
            servicer.ProductAllRead,
            request_deserializer=v1_dot_catalogs_dot_template__pb2.ProductAllReadRequest.FromString,
            response_serializer=v1_dot_catalogs_dot_template__pb2.ProductAllReadResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.catalogs.template.ProductTemplateService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class ProductTemplateService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ProductTemplateCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductTemplateCreate",
            v1_dot_catalogs_dot_template__pb2.ProductTemplateCreateRequest.SerializeToString,
            v1_dot_catalogs_dot_template__pb2.ProductTemplateCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProductTemplateRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductTemplateRead",
            v1_dot_catalogs_dot_template__pb2.ProductTemplateReadRequest.SerializeToString,
            v1_dot_catalogs_dot_template__pb2.ProductTemplateReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProductTemplateUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductTemplateUpdate",
            v1_dot_catalogs_dot_template__pb2.ProductTemplateUpdateRequest.SerializeToString,
            v1_dot_catalogs_dot_template__pb2.ProductTemplateUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProductTemplateDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductTemplateDelete",
            v1_dot_catalogs_dot_template__pb2.ProductTemplateDeleteRequest.SerializeToString,
            v1_dot_catalogs_dot_template__pb2.ProductTemplateDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProductCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductCreate",
            v1_dot_catalogs_dot_template__pb2.ProductCreateRequest.SerializeToString,
            v1_dot_catalogs_dot_template__pb2.ProductCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProductRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductRead",
            v1_dot_catalogs_dot_template__pb2.ProductReadRequest.SerializeToString,
            v1_dot_catalogs_dot_template__pb2.ProductReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProductUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductUpdate",
            v1_dot_catalogs_dot_template__pb2.ProductUpdateRequest.SerializeToString,
            v1_dot_catalogs_dot_template__pb2.ProductUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProductDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductDelete",
            v1_dot_catalogs_dot_template__pb2.ProductDeleteRequest.SerializeToString,
            v1_dot_catalogs_dot_template__pb2.ProductDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ProductAllRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.catalogs.template.ProductTemplateService/ProductAllRead",
            v1_dot_catalogs_dot_template__pb2.ProductAllReadRequest.SerializeToString,
            v1_dot_catalogs_dot_template__pb2.ProductAllReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
