# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/catalogs/template.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.catalogs import family_pb2 as v1_dot_catalogs_dot_family__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1av1/catalogs/template.proto\x12%pro.omni.oms.api.v1.catalogs.template\x1a\x11\x63ommon/base.proto\x1a\x18v1/catalogs/family.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xd5\x01\n\x0fProductTemplate\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12;\n\x06\x66\x61mily\x18\x04 \x01(\x0b\x32+.pro.omni.oms.api.v1.catalogs.family.Family\x12\x31\n\x10\x61ttribute_values\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue"\xb8\x01\n\x1cProductTemplateCreateRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tfamily_id\x18\x03 \x01(\t\x12\x31\n\x10\x61ttribute_values\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xbc\x01\n\x1dProductTemplateCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\x10product_template\x18\x02 \x01(\x0b\x32\x36.pro.omni.oms.api.v1.catalogs.template.ProductTemplate"\xf8\x02\n\x1aProductTemplateReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf6\x01\n\x1bProductTemplateReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12Q\n\x11product_templates\x18\x02 \x03(\x0b\x32\x36.pro.omni.oms.api.v1.catalogs.template.ProductTemplate\x12\x39\n\tmeta_data\x18\x03 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData"\xa8\x01\n\x1cProductTemplateUpdateRequest\x12P\n\x10product_template\x18\x01 \x01(\x0b\x32\x36.pro.omni.oms.api.v1.catalogs.template.ProductTemplate\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xbc\x01\n\x1dProductTemplateUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12P\n\x10product_template\x18\x02 \x01(\x0b\x32\x36.pro.omni.oms.api.v1.catalogs.template.ProductTemplate"b\n\x1cProductTemplateDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"j\n\x1dProductTemplateDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xad\x01\n\x07Product\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1b\n\x13product_template_id\x18\x04 \x01(\t\x12\x31\n\x10\x61ttribute_values\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06\x61\x63tive\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.BoolValue"\xba\x01\n\x14ProductCreateRequest\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1b\n\x13product_template_id\x18\x03 \x01(\t\x12\x31\n\x10\x61ttribute_values\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x15ProductCreateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12?\n\x07product\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.v1.catalogs.template.Product"\xf0\x02\n\x12ProductReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xdd\x01\n\x13ProductReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12@\n\x08products\x18\x02 \x03(\x0b\x32..pro.omni.oms.api.v1.catalogs.template.Product\x12\x39\n\tmeta_data\x18\x03 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData"\x8f\x01\n\x14ProductUpdateRequest\x12?\n\x07product\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.v1.catalogs.template.Product\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xa3\x01\n\x15ProductUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12?\n\x07product\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.v1.catalogs.template.Product"Z\n\x14ProductDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"b\n\x15ProductDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\x84\x01\n\nProductAll\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12\x0f\n\x07img_url\x18\x05 \x01(\t\x12\x1b\n\x13product_template_id\x18\x06 \x01(\t\x12\x12\n\nproduct_id\x18\x07 \x01(\t"\xe7\x02\n\x15ProductAllReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\x36\n\x07\x63ontext\x18\x06 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xe6\x01\n\x16ProductAllReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x46\n\x0bproduct_all\x18\x02 \x03(\x0b\x32\x31.pro.omni.oms.api.v1.catalogs.template.ProductAll\x12\x39\n\tmeta_data\x18\x03 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData2\xf6\n\n\x16ProductTemplateService\x12\xa4\x01\n\x15ProductTemplateCreate\x12\x43.pro.omni.oms.api.v1.catalogs.template.ProductTemplateCreateRequest\x1a\x44.pro.omni.oms.api.v1.catalogs.template.ProductTemplateCreateResponse"\x00\x12\x9e\x01\n\x13ProductTemplateRead\x12\x41.pro.omni.oms.api.v1.catalogs.template.ProductTemplateReadRequest\x1a\x42.pro.omni.oms.api.v1.catalogs.template.ProductTemplateReadResponse"\x00\x12\xa4\x01\n\x15ProductTemplateUpdate\x12\x43.pro.omni.oms.api.v1.catalogs.template.ProductTemplateUpdateRequest\x1a\x44.pro.omni.oms.api.v1.catalogs.template.ProductTemplateUpdateResponse"\x00\x12\xa4\x01\n\x15ProductTemplateDelete\x12\x43.pro.omni.oms.api.v1.catalogs.template.ProductTemplateDeleteRequest\x1a\x44.pro.omni.oms.api.v1.catalogs.template.ProductTemplateDeleteResponse"\x00\x12\x8c\x01\n\rProductCreate\x12;.pro.omni.oms.api.v1.catalogs.template.ProductCreateRequest\x1a<.pro.omni.oms.api.v1.catalogs.template.ProductCreateResponse"\x00\x12\x86\x01\n\x0bProductRead\x12\x39.pro.omni.oms.api.v1.catalogs.template.ProductReadRequest\x1a:.pro.omni.oms.api.v1.catalogs.template.ProductReadResponse"\x00\x12\x8c\x01\n\rProductUpdate\x12;.pro.omni.oms.api.v1.catalogs.template.ProductUpdateRequest\x1a<.pro.omni.oms.api.v1.catalogs.template.ProductUpdateResponse"\x00\x12\x8c\x01\n\rProductDelete\x12;.pro.omni.oms.api.v1.catalogs.template.ProductDeleteRequest\x1a<.pro.omni.oms.api.v1.catalogs.template.ProductDeleteResponse"\x00\x12\x8f\x01\n\x0eProductAllRead\x12<.pro.omni.oms.api.v1.catalogs.template.ProductAllReadRequest\x1a=.pro.omni.oms.api.v1.catalogs.template.ProductAllReadResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.catalogs.template_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_PRODUCTTEMPLATE"]._serialized_start = 177
    _globals["_PRODUCTTEMPLATE"]._serialized_end = 390
    _globals["_PRODUCTTEMPLATECREATEREQUEST"]._serialized_start = 393
    _globals["_PRODUCTTEMPLATECREATEREQUEST"]._serialized_end = 577
    _globals["_PRODUCTTEMPLATECREATERESPONSE"]._serialized_start = 580
    _globals["_PRODUCTTEMPLATECREATERESPONSE"]._serialized_end = 768
    _globals["_PRODUCTTEMPLATEREADREQUEST"]._serialized_start = 771
    _globals["_PRODUCTTEMPLATEREADREQUEST"]._serialized_end = 1147
    _globals["_PRODUCTTEMPLATEREADRESPONSE"]._serialized_start = 1150
    _globals["_PRODUCTTEMPLATEREADRESPONSE"]._serialized_end = 1396
    _globals["_PRODUCTTEMPLATEUPDATEREQUEST"]._serialized_start = 1399
    _globals["_PRODUCTTEMPLATEUPDATEREQUEST"]._serialized_end = 1567
    _globals["_PRODUCTTEMPLATEUPDATERESPONSE"]._serialized_start = 1570
    _globals["_PRODUCTTEMPLATEUPDATERESPONSE"]._serialized_end = 1758
    _globals["_PRODUCTTEMPLATEDELETEREQUEST"]._serialized_start = 1760
    _globals["_PRODUCTTEMPLATEDELETEREQUEST"]._serialized_end = 1858
    _globals["_PRODUCTTEMPLATEDELETERESPONSE"]._serialized_start = 1860
    _globals["_PRODUCTTEMPLATEDELETERESPONSE"]._serialized_end = 1966
    _globals["_PRODUCT"]._serialized_start = 1969
    _globals["_PRODUCT"]._serialized_end = 2142
    _globals["_PRODUCTCREATEREQUEST"]._serialized_start = 2145
    _globals["_PRODUCTCREATEREQUEST"]._serialized_end = 2331
    _globals["_PRODUCTCREATERESPONSE"]._serialized_start = 2334
    _globals["_PRODUCTCREATERESPONSE"]._serialized_end = 2497
    _globals["_PRODUCTREADREQUEST"]._serialized_start = 2500
    _globals["_PRODUCTREADREQUEST"]._serialized_end = 2868
    _globals["_PRODUCTREADRESPONSE"]._serialized_start = 2871
    _globals["_PRODUCTREADRESPONSE"]._serialized_end = 3092
    _globals["_PRODUCTUPDATEREQUEST"]._serialized_start = 3095
    _globals["_PRODUCTUPDATEREQUEST"]._serialized_end = 3238
    _globals["_PRODUCTUPDATERESPONSE"]._serialized_start = 3241
    _globals["_PRODUCTUPDATERESPONSE"]._serialized_end = 3404
    _globals["_PRODUCTDELETEREQUEST"]._serialized_start = 3406
    _globals["_PRODUCTDELETEREQUEST"]._serialized_end = 3496
    _globals["_PRODUCTDELETERESPONSE"]._serialized_start = 3498
    _globals["_PRODUCTDELETERESPONSE"]._serialized_end = 3596
    _globals["_PRODUCTALL"]._serialized_start = 3599
    _globals["_PRODUCTALL"]._serialized_end = 3731
    _globals["_PRODUCTALLREADREQUEST"]._serialized_start = 3734
    _globals["_PRODUCTALLREADREQUEST"]._serialized_end = 4093
    _globals["_PRODUCTALLREADRESPONSE"]._serialized_start = 4096
    _globals["_PRODUCTALLREADRESPONSE"]._serialized_end = 4326
    _globals["_PRODUCTTEMPLATESERVICE"]._serialized_start = 4329
    _globals["_PRODUCTTEMPLATESERVICE"]._serialized_end = 5727
# @@protoc_insertion_point(module_scope)
