# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/payment_method.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n!v1/utilities/payment_method.proto\x12,pro.omni.oms.api.v1.utilities.payment_method\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xb9\x01\n\rPaymentMethod\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12*\n\x06\x61\x63tive\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\x06 \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\x92\x01\n\x17PaymentMethodAddRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0e\n\x06\x61\x63tive\x18\x04 \x01(\x08\x12\x36\n\x07\x63ontext\x18\x05 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xba\x01\n\x18PaymentMethodAddResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12S\n\x0epayment_method\x18\x02 \x01(\x0b\x32;.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethod"\xf6\x02\n\x18PaymentMethodReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xf7\x01\n\x19PaymentMethodReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12T\n\x0fpayment_methods\x18\x03 \x03(\x0b\x32;.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethod"\xa9\x01\n\x1aPaymentMethodUpdateRequest\x12S\n\x0epayment_method\x18\x01 \x01(\x0b\x32;.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethod\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xbd\x01\n\x1bPaymentMethodUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12S\n\x0epayment_method\x18\x02 \x01(\x0b\x32;.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethod"`\n\x1aPaymentMethodDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"h\n\x1bPaymentMethodDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xc3\x05\n\x14PaymentMethodService\x12\xa3\x01\n\x10PaymentMethodAdd\x12\x45.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodAddRequest\x1a\x46.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodAddResponse"\x00\x12\xa6\x01\n\x11PaymentMethodRead\x12\x46.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodReadRequest\x1aG.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodReadResponse"\x00\x12\xac\x01\n\x13PaymentMethodUpdate\x12H.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodUpdateRequest\x1aI.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodUpdateResponse"\x00\x12\xac\x01\n\x13PaymentMethodDelete\x12H.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodDeleteRequest\x1aI.pro.omni.oms.api.v1.utilities.payment_method.PaymentMethodDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.payment_method_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_PAYMENTMETHOD"]._serialized_start = 135
    _globals["_PAYMENTMETHOD"]._serialized_end = 320
    _globals["_PAYMENTMETHODADDREQUEST"]._serialized_start = 323
    _globals["_PAYMENTMETHODADDREQUEST"]._serialized_end = 469
    _globals["_PAYMENTMETHODADDRESPONSE"]._serialized_start = 472
    _globals["_PAYMENTMETHODADDRESPONSE"]._serialized_end = 658
    _globals["_PAYMENTMETHODREADREQUEST"]._serialized_start = 661
    _globals["_PAYMENTMETHODREADREQUEST"]._serialized_end = 1035
    _globals["_PAYMENTMETHODREADRESPONSE"]._serialized_start = 1038
    _globals["_PAYMENTMETHODREADRESPONSE"]._serialized_end = 1285
    _globals["_PAYMENTMETHODUPDATEREQUEST"]._serialized_start = 1288
    _globals["_PAYMENTMETHODUPDATEREQUEST"]._serialized_end = 1457
    _globals["_PAYMENTMETHODUPDATERESPONSE"]._serialized_start = 1460
    _globals["_PAYMENTMETHODUPDATERESPONSE"]._serialized_end = 1649
    _globals["_PAYMENTMETHODDELETEREQUEST"]._serialized_start = 1651
    _globals["_PAYMENTMETHODDELETEREQUEST"]._serialized_end = 1747
    _globals["_PAYMENTMETHODDELETERESPONSE"]._serialized_start = 1749
    _globals["_PAYMENTMETHODDELETERESPONSE"]._serialized_end = 1853
    _globals["_PAYMENTMETHODSERVICE"]._serialized_start = 1856
    _globals["_PAYMENTMETHODSERVICE"]._serialized_end = 2563
# @@protoc_insertion_point(module_scope)
