# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/rules/delivery_shipper.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2
from omni.pro.protos.v1.rules import carrier_pb2 as v1_dot_rules_dot_carrier__pb2
from omni.pro.protos.v1.rules import delivery_locality_pb2 as v1_dot_rules_dot_delivery__locality__pb2
from omni.pro.protos.v1.rules import delivery_method_pb2 as v1_dot_rules_dot_delivery__method__pb2
from omni.pro.protos.v1.rules import schedule_work_pb2 as v1_dot_rules_dot_schedule__work__pb2
from omni.pro.protos.v1.rules import warehouse_pb2 as v1_dot_rules_dot_warehouse__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x1fv1/rules/delivery_shipper.proto\x12*pro.omni.oms.api.v1.rules.delivery_shipper\x1a\x11\x63ommon/base.proto\x1a\x1ev1/rules/delivery_method.proto\x1a\x16v1/rules/carrier.proto\x1a\x18v1/rules/warehouse.proto\x1a\x1cv1/rules/schedule_work.proto\x1a v1/rules/delivery_locality.proto\x1a\x1egoogle/protobuf/wrappers.proto"\x97\x05\n\x0f\x44\x65liveryShipper\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x44\n\x10\x64\x65livery_carrier\x18\x04 \x01(\x0b\x32*.pro.omni.oms.api.v1.rules.carrier.Carrier\x12S\n\x10\x64\x65livery_methods\x18\x05 \x03(\x0b\x32\x39.pro.omni.oms.api.v1.rules.delivery_method.DeliveryMethod\x12\x16\n\x0emaximum_weight\x18\x06 \x01(\x02\x12\x16\n\x0emaximum_volume\x18\x07 \x01(\x02\x12N\n\x0fschedule_pickup\x18\x08 \x01(\x0b\x32\x35.pro.omni.oms.api.v1.rules.schedule_work.ScheduleWork\x12Y\n\x12locality_available\x18\t \x01(\x0b\x32=.pro.omni.oms.api.v1.rules.delivery_locality.DeliveryLocality\x12\x35\n\x11internal_transfer\x18\n \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x42\n\nwarehouses\x18\x0b \x03(\x0b\x32..pro.omni.oms.api.v1.rules.warehouse.Warehouse\x12*\n\x06\x61\x63tive\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\r \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xe5\x02\n\x1c\x44\x65liveryShipperCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x1b\n\x13\x64\x65livery_carrier_id\x18\x03 \x01(\x05\x12\x1b\n\x13\x64\x65livery_method_ids\x18\x04 \x01(\t\x12\x16\n\x0emaximum_weight\x18\x05 \x01(\x02\x12\x16\n\x0emaximum_volume\x18\x06 \x01(\x02\x12\x1a\n\x12schedule_pickup_id\x18\x07 \x01(\t\x12\x1d\n\x15locality_available_id\x18\x08 \x01(\t\x12\x35\n\x11internal_transfer\x18\t \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x15\n\rwarehouse_ids\x18\n \x01(\t\x12\x36\n\x07\x63ontext\x18\x0b \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc1\x01\n\x1d\x44\x65liveryShipperCreateResponse\x12U\n\x10\x64\x65livery_shipper\x18\x01 \x01(\x0b\x32;.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipper\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xf8\x02\n\x1a\x44\x65liveryShipperReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xfb\x01\n\x1b\x44\x65liveryShipperReadResponse\x12V\n\x11\x64\x65livery_shippers\x18\x01 \x03(\x0b\x32;.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipper\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12I\n\x11response_standard\x18\x03 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"\xad\x01\n\x1c\x44\x65liveryShipperUpdateRequest\x12U\n\x10\x64\x65livery_shipper\x18\x01 \x01(\x0b\x32;.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipper\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xc1\x01\n\x1d\x44\x65liveryShipperUpdateResponse\x12U\n\x10\x64\x65livery_shipper\x18\x01 \x01(\x0b\x32;.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipper\x12I\n\x11response_standard\x18\x02 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard"b\n\x1c\x44\x65liveryShipperDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"j\n\x1d\x44\x65liveryShipperDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xd6\x05\n\x16\x44\x65liveryShipperService\x12\xae\x01\n\x15\x44\x65liveryShipperCreate\x12H.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperCreateRequest\x1aI.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperCreateResponse"\x00\x12\xa8\x01\n\x13\x44\x65liveryShipperRead\x12\x46.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperReadRequest\x1aG.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperReadResponse"\x00\x12\xae\x01\n\x15\x44\x65liveryShipperUpdate\x12H.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperUpdateRequest\x1aI.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperUpdateResponse"\x00\x12\xae\x01\n\x15\x44\x65liveryShipperDelete\x12H.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperDeleteRequest\x1aI.pro.omni.oms.api.v1.rules.delivery_shipper.DeliveryShipperDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.rules.delivery_shipper_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_DELIVERYSHIPPER"]._serialized_start = 277
    _globals["_DELIVERYSHIPPER"]._serialized_end = 940
    _globals["_DELIVERYSHIPPERCREATEREQUEST"]._serialized_start = 943
    _globals["_DELIVERYSHIPPERCREATEREQUEST"]._serialized_end = 1300
    _globals["_DELIVERYSHIPPERCREATERESPONSE"]._serialized_start = 1303
    _globals["_DELIVERYSHIPPERCREATERESPONSE"]._serialized_end = 1496
    _globals["_DELIVERYSHIPPERREADREQUEST"]._serialized_start = 1499
    _globals["_DELIVERYSHIPPERREADREQUEST"]._serialized_end = 1875
    _globals["_DELIVERYSHIPPERREADRESPONSE"]._serialized_start = 1878
    _globals["_DELIVERYSHIPPERREADRESPONSE"]._serialized_end = 2129
    _globals["_DELIVERYSHIPPERUPDATEREQUEST"]._serialized_start = 2132
    _globals["_DELIVERYSHIPPERUPDATEREQUEST"]._serialized_end = 2305
    _globals["_DELIVERYSHIPPERUPDATERESPONSE"]._serialized_start = 2308
    _globals["_DELIVERYSHIPPERUPDATERESPONSE"]._serialized_end = 2501
    _globals["_DELIVERYSHIPPERDELETEREQUEST"]._serialized_start = 2503
    _globals["_DELIVERYSHIPPERDELETEREQUEST"]._serialized_end = 2601
    _globals["_DELIVERYSHIPPERDELETERESPONSE"]._serialized_start = 2603
    _globals["_DELIVERYSHIPPERDELETERESPONSE"]._serialized_end = 2709
    _globals["_DELIVERYSHIPPERSERVICE"]._serialized_start = 2712
    _globals["_DELIVERYSHIPPERSERVICE"]._serialized_end = 3438
# @@protoc_insertion_point(module_scope)
