# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
from omni.pro.protos.v1.sales import client_pb2 as v1_dot_sales_dot_client__pb2


class ClientServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ClientCreate = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.client.ClientService/ClientCreate",
            request_serializer=v1_dot_sales_dot_client__pb2.ClientCreateRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_client__pb2.ClientCreateResponse.FromString,
        )
        self.ClientRead = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.client.ClientService/ClientRead",
            request_serializer=v1_dot_sales_dot_client__pb2.ClientReadRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_client__pb2.ClientReadResponse.FromString,
        )
        self.ClientUpdate = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.client.ClientService/ClientUpdate",
            request_serializer=v1_dot_sales_dot_client__pb2.ClientUpdateRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_client__pb2.ClientUpdateResponse.FromString,
        )
        self.ClientDelete = channel.unary_unary(
            "/pro.omni.oms.api.v1.sales.client.ClientService/ClientDelete",
            request_serializer=v1_dot_sales_dot_client__pb2.ClientDeleteRequest.SerializeToString,
            response_deserializer=v1_dot_sales_dot_client__pb2.ClientDeleteResponse.FromString,
        )


class ClientServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ClientCreate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ClientRead(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ClientUpdate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ClientDelete(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_ClientServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "ClientCreate": grpc.unary_unary_rpc_method_handler(
            servicer.ClientCreate,
            request_deserializer=v1_dot_sales_dot_client__pb2.ClientCreateRequest.FromString,
            response_serializer=v1_dot_sales_dot_client__pb2.ClientCreateResponse.SerializeToString,
        ),
        "ClientRead": grpc.unary_unary_rpc_method_handler(
            servicer.ClientRead,
            request_deserializer=v1_dot_sales_dot_client__pb2.ClientReadRequest.FromString,
            response_serializer=v1_dot_sales_dot_client__pb2.ClientReadResponse.SerializeToString,
        ),
        "ClientUpdate": grpc.unary_unary_rpc_method_handler(
            servicer.ClientUpdate,
            request_deserializer=v1_dot_sales_dot_client__pb2.ClientUpdateRequest.FromString,
            response_serializer=v1_dot_sales_dot_client__pb2.ClientUpdateResponse.SerializeToString,
        ),
        "ClientDelete": grpc.unary_unary_rpc_method_handler(
            servicer.ClientDelete,
            request_deserializer=v1_dot_sales_dot_client__pb2.ClientDeleteRequest.FromString,
            response_serializer=v1_dot_sales_dot_client__pb2.ClientDeleteResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "pro.omni.oms.api.v1.sales.client.ClientService", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))


# This class is part of an EXPERIMENTAL API.
class ClientService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ClientCreate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.client.ClientService/ClientCreate",
            v1_dot_sales_dot_client__pb2.ClientCreateRequest.SerializeToString,
            v1_dot_sales_dot_client__pb2.ClientCreateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ClientRead(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.client.ClientService/ClientRead",
            v1_dot_sales_dot_client__pb2.ClientReadRequest.SerializeToString,
            v1_dot_sales_dot_client__pb2.ClientReadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ClientUpdate(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.client.ClientService/ClientUpdate",
            v1_dot_sales_dot_client__pb2.ClientUpdateRequest.SerializeToString,
            v1_dot_sales_dot_client__pb2.ClientUpdateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )

    @staticmethod
    def ClientDelete(
        request,
        target,
        options=(),
        channel_credentials=None,
        call_credentials=None,
        insecure=False,
        compression=None,
        wait_for_ready=None,
        timeout=None,
        metadata=None,
    ):
        return grpc.experimental.unary_unary(
            request,
            target,
            "/pro.omni.oms.api.v1.sales.client.ClientService/ClientDelete",
            v1_dot_sales_dot_client__pb2.ClientDeleteRequest.SerializeToString,
            v1_dot_sales_dot_client__pb2.ClientDeleteResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
        )
