# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: v1/utilities/tax.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from omni.pro.protos.common import base_pb2 as common_dot_base__pb2

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x16v1/utilities/tax.proto\x12!pro.omni.oms.api.v1.utilities.tax\x1a\x11\x63ommon/base.proto\x1a\x1egoogle/protobuf/wrappers.proto"\xe4\x01\n\x03Tax\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t\x12\x0c\n\x04rate\x18\x04 \x01(\x02\x12\x10\n\x08rounding\x18\x05 \x01(\x01\x12\x16\n\x0e\x64\x65\x63imal_places\x18\x06 \x01(\x05\x12\x10\n\x08position\x18\x07 \x01(\t\x12*\n\x06\x61\x63tive\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12?\n\x0cobject_audit\x18\t \x01(\x0b\x32).pro.omni.oms.api.common.base.ObjectAudit"\xad\x01\n\rTaxAddRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0c\n\x04rate\x18\x03 \x01(\x02\x12\x10\n\x08rounding\x18\x04 \x01(\x01\x12\x16\n\x0e\x64\x65\x63imal_places\x18\x05 \x01(\x05\x12\x10\n\x08position\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x90\x01\n\x0eTaxAddResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x33\n\x03tax\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.utilities.tax.Tax"\xec\x02\n\x0eTaxReadRequest\x12\x37\n\x08group_by\x18\x01 \x03(\x0b\x32%.pro.omni.oms.api.common.base.GroupBy\x12\x35\n\x07sort_by\x18\x02 \x01(\x0b\x32$.pro.omni.oms.api.common.base.SortBy\x12\x34\n\x06\x66ields\x18\x03 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Fields\x12\x34\n\x06\x66ilter\x18\x04 \x01(\x0b\x32$.pro.omni.oms.api.common.base.Filter\x12:\n\tpaginated\x18\x05 \x01(\x0b\x32\'.pro.omni.oms.api.common.base.Paginated\x12\n\n\x02id\x18\x06 \x01(\t\x12\x36\n\x07\x63ontext\x18\x07 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\xce\x01\n\x0fTaxReadResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x39\n\tmeta_data\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.common.base.MetaData\x12\x35\n\x05taxes\x18\x03 \x03(\x0b\x32&.pro.omni.oms.api.v1.utilities.tax.Tax"\x7f\n\x10TaxUpdateRequest\x12\x33\n\x03tax\x18\x01 \x01(\x0b\x32&.pro.omni.oms.api.v1.utilities.tax.Tax\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"\x93\x01\n\x11TaxUpdateResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard\x12\x33\n\x03tax\x18\x02 \x01(\x0b\x32&.pro.omni.oms.api.v1.utilities.tax.Tax"V\n\x10TaxDeleteRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x36\n\x07\x63ontext\x18\x02 \x01(\x0b\x32%.pro.omni.oms.api.common.base.Context"^\n\x11TaxDeleteResponse\x12I\n\x11response_standard\x18\x01 \x01(\x0b\x32..pro.omni.oms.api.common.base.ResponseStandard2\xe5\x03\n\nTaxService\x12o\n\x06TaxAdd\x12\x30.pro.omni.oms.api.v1.utilities.tax.TaxAddRequest\x1a\x31.pro.omni.oms.api.v1.utilities.tax.TaxAddResponse"\x00\x12r\n\x07TaxRead\x12\x31.pro.omni.oms.api.v1.utilities.tax.TaxReadRequest\x1a\x32.pro.omni.oms.api.v1.utilities.tax.TaxReadResponse"\x00\x12x\n\tTaxUpdate\x12\x33.pro.omni.oms.api.v1.utilities.tax.TaxUpdateRequest\x1a\x34.pro.omni.oms.api.v1.utilities.tax.TaxUpdateResponse"\x00\x12x\n\tTaxDelete\x12\x33.pro.omni.oms.api.v1.utilities.tax.TaxDeleteRequest\x1a\x34.pro.omni.oms.api.v1.utilities.tax.TaxDeleteResponse"\x00\x62\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "v1.utilities.tax_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    DESCRIPTOR._options = None
    _globals["_TAX"]._serialized_start = 113
    _globals["_TAX"]._serialized_end = 341
    _globals["_TAXADDREQUEST"]._serialized_start = 344
    _globals["_TAXADDREQUEST"]._serialized_end = 517
    _globals["_TAXADDRESPONSE"]._serialized_start = 520
    _globals["_TAXADDRESPONSE"]._serialized_end = 664
    _globals["_TAXREADREQUEST"]._serialized_start = 667
    _globals["_TAXREADREQUEST"]._serialized_end = 1031
    _globals["_TAXREADRESPONSE"]._serialized_start = 1034
    _globals["_TAXREADRESPONSE"]._serialized_end = 1240
    _globals["_TAXUPDATEREQUEST"]._serialized_start = 1242
    _globals["_TAXUPDATEREQUEST"]._serialized_end = 1369
    _globals["_TAXUPDATERESPONSE"]._serialized_start = 1372
    _globals["_TAXUPDATERESPONSE"]._serialized_end = 1519
    _globals["_TAXDELETEREQUEST"]._serialized_start = 1521
    _globals["_TAXDELETEREQUEST"]._serialized_end = 1607
    _globals["_TAXDELETERESPONSE"]._serialized_start = 1609
    _globals["_TAXDELETERESPONSE"]._serialized_end = 1703
    _globals["_TAXSERVICE"]._serialized_start = 1706
    _globals["_TAXSERVICE"]._serialized_end = 2191
# @@protoc_insertion_point(module_scope)
